@@ -125,7 +125,8 @@ def _merge_funcs_and_named_funcs(funcs, named_funcs):
         named_funcs
     ), f"Some names clashed: {', '.join(set(named_funcs_obtained_from_funcs).intersection(named_funcs))}"
     funcs = (
-        tuple(named_funcs_obtained_from_funcs.values()) + funcs_obtained_from_named_funcs
+        tuple(named_funcs_obtained_from_funcs.values())
+        + funcs_obtained_from_named_funcs
     )
     return (
         funcs,
@@ -208,7 +209,9 @@ def name_with_varkind_and_default_marker(param: Parameter) -> str:
             return ""
 
     return (
-        kind_marker(param) + f"{param.name}" + ("=" if param.default is not empty else "")
+        kind_marker(param)
+        + f"{param.name}"
+        + ("=" if param.default is not empty else "")
     )
 
 
